summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2012-07-10 21:48:20 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2012-07-12 13:13:01 -0500
commitc86cf4b7e40a3baf17b8e6ab2526b63e71d28700 (patch)
treee118d1f59c7febb319ea28ba0b85d1c20d06d650 /png.h
parent981560ae6094f0b0557e82c33d7ae5f7d81ca0ea (diff)
downloadlibpng-c86cf4b7e40a3baf17b8e6ab2526b63e71d28700.tar.gz
[master] Imported from libpng-1.5.12.tar
Diffstat (limited to 'png.h')
-rw-r--r--png.h21
1 files changed, 11 insertions, 10 deletions
diff --git a/png.h b/png.h
index b1c9e7243..4c37e58a4 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.5.11 - June 14, 2012
* Copyright (c) 1998-2012 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.5.11 - June 14, 2012: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -177,6 +177,7 @@
* 1.5.11beta01 15 10511 15.so.15.11[.0]
* 1.5.11rc01-05 15 10511 15.so.15.11[.0]
* 1.5.11 15 10511 15.so.15.11[.0]
+ * 1.5.12 15 10512 15.so.15.12[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -208,7 +209,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.5.11, June 14, 2012, are
* Copyright (c) 2004, 2006-2012 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -320,13 +321,13 @@
* Y2K compliance in libpng:
* =========================
*
- * June 14, 2012
+ * July 11, 2012
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.5.11 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*
* Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -385,9 +386,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.5.11"
+#define PNG_LIBPNG_VER_STRING "1.5.12"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.5.11 - June 14, 2012\n"
+ " libpng version 1.5.12 - July 11, 2012\n"
#define PNG_LIBPNG_VER_SONUM 15
#define PNG_LIBPNG_VER_DLLNUM 15
@@ -395,7 +396,7 @@
/* These should match the first 3 components of PNG_LIBPNG_VER_STRING: */
#define PNG_LIBPNG_VER_MAJOR 1
#define PNG_LIBPNG_VER_MINOR 5
-#define PNG_LIBPNG_VER_RELEASE 11
+#define PNG_LIBPNG_VER_RELEASE 12
/* This should match the numeric part of the final component of
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
@@ -426,7 +427,7 @@
* version 1.0.0 was mis-numbered 100 instead of 10000). From
* version 1.0.1 it's xxyyzz, where x=major, y=minor, z=release
*/
-#define PNG_LIBPNG_VER 10511 /* 1.5.11 */
+#define PNG_LIBPNG_VER 10512 /* 1.5.12 */
/* Library configuration: these options cannot be changed after
* the library has been built.
@@ -548,7 +549,7 @@ extern "C" {
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef char* png_libpng_version_1_5_11;
+typedef char* png_libpng_version_1_5_12;
/* Three color definitions. The order of the red, green, and blue, (and the
* exact size) is not important, although the size of the fields need to
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.5.11 - June 14, 2012
+ * libpng version 1.5.12 - July 11, 2012
* Copyright (c) 1998-2012 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.5.11 - June 14, 2012: Glenn
+ * libpng versions 0.97, January 1998, through 1.5.12 - July 11, 2012: Glenn
* See also "Contributing Authors", below.
*
@@ -208,7 +209,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.5.11, June 14, 2012, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.12, July 11, 2012, are
* Copyright (c) 2004, 2006-2012 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -320,13 +321,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.5.11 are Y2K compliant. It is my belief that
+ * upward through 1.5.12 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*